=======
Credits
=======

We kindly request that you cite the following article for the use of PyXRF.

Li Li, Hanfei Yan, Wei Xu, Dantong Yu, Annie Heroux, Wah-Keat Lee, Stuart I. Campbell and Yong S. Chu, “PyXRF: Python-based X-ray fluorescence analysis package”, Proceedings Volume 10389, X-Ray Nanoimaging: Instruments and Methods III; 103890U (2017); doi: 10.1117/12.2272585

http://dx.doi.org/10.1117/12.2272585
